/*
 * Copyright (C) 2012 Canonical Ltd
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 3 as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Authored by Pawel Stolowski <pawel.stolowski@canonical.com>
 *
 */

namespace Unity.ShoppingLens
{
  namespace MarkupCleaner
  {
    internal static bool replace_cb (MatchInfo match, StringBuilder result)
    {
      string? val = match.fetch (0);
      if (val != null)
      {
        val = val.down ();
        if (val == "b") {
          result.append ("b");
        }
        else if (val == "&") {
          result.append ("&amp;");
        }
        /* else - ignore all other html tags */
      }
      return false;
    }
    
    public static string html_to_pango_markup (string html_text)
    {
      /* match any html <..> tag and also some special characters such as &, unless it's &amp; already */
      try
      {
        var html_markup_re = new GLib.Regex ("(<.*?>)|(\\&(?!amp;))", GLib.RegexCompileFlags.MULTILINE);
        return html_markup_re.replace_eval (html_text, html_text.length, 0, 0, replace_cb);
      }
      catch (GLib.RegexError e) // this shouldn't really happen.. if it happens, it's a programming error
      {
        warning ("Regex compilation failed: %s", e.message);
      }
      return html_text;
    }
  }
}